==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_hmenu_plus.js <==
/**
 * Horizontal menu object
 *
 * <p item>	is text content of menu
 *			if value is equal to '-' than <hr> tag is used instead of link
 *
 * Input array example:
 * x[<p item>]	[arg] = obj | string
 *				[disabled]
 *				[css] = 'className'
 *				[nodes][<ch item>]	[arg]
 *									[css]
 *									[nodes]
 **/
_me = obj_hmenu_plus.prototype;
function obj_hmenu_plus(){};

_me.__constructor = function(){
	var me = this;

	this.__ePull;
	this.__openedNode;
	this.__timeout;

	//this._main.onmouseover =
	this._main.onmousemove = function(e){

		var e = e || window.event;
		var elm = e.target || e.srcElement;



		if (elm.tagName != 'A') return false;

		if (me.__timeout){
			window.clearTimeout(me.__timeout);
			me.__timeout = null;
		}

		var id =  me.__getId(elm.id);

		if (me.__openedNode === id) return false;

		// open new nodes
		if (me.__aData[id] && typeof me.__aData[id].nodes == 'object'){

			if (!me.__ePull){

				me.__ePull = mkElement('div');
				me.__ePull.className = 'obj_hmenu_plus';
				me.__ePull.onclick = me._main.onclick;

				me.__openedNode = null;

				me.__ePull.onmousemove = function(e){
					if (me.__timeout){
						window.clearTimeout(me.__timeout);
						me.__timeout = null;
					}
				};
				me.__ePull.onmouseout = function(e){
                    me.__timeout = window.setTimeout(me._pathName+'.__close();',100);
				};

				document.body.appendChild(me.__ePull);
			}
			else
			if (me.__openedNode!==id){
				me.__ePull.innerHTML = '';
				me.__ePull.style.display = 'block';
			}
			else
				return false;

			me.__openedNode = id;

			// positione
            var pos = getSize(elm);
			me.__ePull.style.left = pos.x;
			me.__ePull.style.top = pos.y+pos.h;
			
            me.__ePull.appendChild(me.__row(me.__aData[id].nodes,id));
		}
		// try to close old nodes
		else
		if (me.__ePull)
			me.__close();

	};

	this._main.onmouseout = function(e){
		var e = e || window.event;
		var elm = e.target || e.srcElement;

		if (elm.tagName != 'A') return false;
		me.__timeout = window.setTimeout(me._pathName+'.__close();',100);
	};
	
	this._add_destructor('__close',[1]);
};

_me.__close = function(fully){

	//clear timeout
	if (this.__timeout){
		window.clearTimeout(this.__timeout);
		this.__timeout = null;
	}
	//close popup
	try{
		if (this.__ePull) {
			if (fully){
				this.__ePull.parentNode.removeChild(this.__ePull);
				this.__ePull = null;
			}
			else
				this.__ePull.style.display = 'none';
		}
	}
	catch(er){}
	this.__openedNode = null;
};

_me.__getId = function(elmid){
	return elmid.substr(this._pathName.length+1);
};

_me._fill = function (aData){

	this._clear();
	
	/* retrieve data from dataset */
	if (!aData && this._listener)
		this.__aData = dataSet.get(this._listener,this._listenerPath);
	else
		this.__aData = aData;

	if (!this.__aData) return;

	aData = clone(this.__aData,true);
	for(var i in aData){
		if (aData[i]['nodes']){
			delete aData[i]['nodes'];
			aData[i]['css'] = aData[i]['css']?aData[i]['css']+ ' nodes':'nodes';
		}
	}

	this.__row(aData);
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_hmenu_plus.js <==
/**
 * Horizontal menu object
 *
 * <p item>	is text content of menu
 *			if value is equal to '-' than <hr> tag is used instead of link
 *
 * Input array example:
 * x[<p item>]	[arg] = obj | string
 *				[disabled]
 *				[css] = 'className'
 *				[nodes][<ch item>]	[arg]
 *									[css]
 *									[nodes]
 **/
_me = obj_hmenu_plus.prototype;
function obj_hmenu_plus(){};

_me.__constructor = function(){
	var me = this;

	this.__ePull;
	this.__openedNode;
	this.__timeout;

	this._main.onmousemove = function(e){

		var e = e || window.event;
		var elm = e.target || e.srcElement;



		if (elm.tagName != 'A') return false;

		if (me.__timeout){
			window.clearTimeout(me.__timeout);
			me.__timeout = null;
		}

		var id =  me.__getId(elm.id);

		if (me.__openedNode === id) return false;

		// open new nodes
		if (me.__aData[id] && typeof me.__aData[id].nodes == 'object'){

			if (!me.__ePull){

				me.__ePull = mkElement('div');
				me.__ePull.className = 'obj_hmenu_plus'+(me._css?' '+me._css+'_plus':'');
				me.__ePull.onclick = me._main.onclick;

				me.__openedNode = null;

				me.__ePull.onmousemove = function(e){
					if (me.__timeout){
						window.clearTimeout(me.__timeout);
						me.__timeout = null;
					}
				};
				me.__ePull.onmouseout = function(e){
					me.__timeout = window.setTimeout(me._pathName+'.__close();',100);
				};

				document.body.appendChild(me.__ePull);
			}
			else
			if (me.__openedNode!==id){
				me.__ePull.innerHTML = '';
				me.__ePull.style.display = 'block';

				//odznacit parent elm
				if (typeof me.__openedNode != 'undefined'){
					var prt = document.getElementById(me._pathName+'/'+me.__openedNode);
					if (prt){
					    removecss(prt,'active');
					    prt = null;
					}
				}
			}
			else
				return false;

			me.__openedNode = id;

			//oznacit parent elm
			var prt = document.getElementById(me._pathName+'/'+me.__openedNode);
			if (prt){
 				addcss(prt,'active');
			    prt = null;
			}

			// positione
			var pos = getSize(elm);
			me.__ePull.style.left = pos.x;
			me.__ePull.style.top = pos.y+pos.h;

			me.__ePull.appendChild(me.__row(me.__aData[id].nodes,id));
		}
		// try to close old nodes
		else
		if (me.__ePull)
			me.__close();

	};

	this._main.onmouseout = function(e){
		var e = e || window.event;
		var elm = e.target || e.srcElement;

		if (elm.tagName != 'A') return false;
		me.__timeout = window.setTimeout('try{'+me._pathName+'.__close();}catch(r){}',100);
	};

	this._add_destructor('__close',[1]);
};

_me.__close = function(fully){

	//clear timeout
	if (this.__timeout){
		window.clearTimeout(this.__timeout);
		this.__timeout = null;
	}
	//close popup
	try{
		if (this.__ePull) {
			if (fully){
				this.__ePull.parentNode.removeChild(this.__ePull);
				this.__ePull = null;
			}
			else
				this.__ePull.style.display = 'none';
		}
	}
	catch(er){}

	if (this.__openedNode){
		var elm = document.getElementById(this._pathName+'/'+this.__openedNode);
		if (elm){
		    removecss(elm,'active');
			elm = null;
		}
	}

	this.__openedNode = null;
};

_me.__getId = function(elmid){
	return elmid.substr(this._pathName.length+1);
};

_me._fill = function (aData){

	this._clear();

	/* retrieve data from dataset */
	if (!aData && this._listener)
		this.__aData = dataSet.get(this._listener,this._listenerPath);
	else
		this.__aData = aData;

	if (!this.__aData) return;

	aData = clone(this.__aData,true);
	for(var i in aData){
		if (aData[i]['nodes']){
			delete aData[i]['nodes'];
			aData[i]['css'] = aData[i]['css']?aData[i]['css']+ ' nodes':'nodes';
		}
	}

	this.__row(aData);
};
